using Syncfusion.RangeNavigator.XForms;
using Syncfusion.SfChart.XForms;
using System;
using System.Collections.Generic;
using System.Text;
using System.Threading;
using Xamarin.Forms;

namespace RangeNavigatorSample
{
    public class GraphsView : ContentPage
    {
        SfDateTimeRangeNavigator rangeNavigator;

        SfChart chart;

        SfChart contentChart;

        DateTimeAxis primaryAxis;
        public GraphsView()
        {
            this.BindingContext = new RangeNavViewModel();

            Content = GetLayout();
        }

        protected override void OnBindingContextChanged()
        {
            base.OnBindingContextChanged();

            contentChart = new SfChart();

            contentChart.BindingContext = this.BindingContext;
        }

        View GetLayout()
        {
            #region Chart 

            chart = new SfChart();

            primaryAxis = new DateTimeAxis();
            chart.PrimaryAxis = primaryAxis;

            NumericalAxis secondaryAxis = new NumericalAxis();
            chart.SecondaryAxis = secondaryAxis;

            FastLineSeries series = new FastLineSeries();
            series.SetBinding(ChartSeries.ItemsSourceProperty, "DateTimeRangeData");
            series.XBindingPath = "XValue";
            series.YBindingPath = "YValue";
            chart.Series.Add(series);

            #endregion

            #region DateTimeRangeNavigator 

            rangeNavigator = new SfDateTimeRangeNavigator();
            
            switch(Device.RuntimePlatform)
            {
                case Device.Android:
                    rangeNavigator.DeferredUpdateDelay = double.PositiveInfinity;
                    break;
                case Device.iOS:
                    rangeNavigator.DeferredUpdateDelay = double.PositiveInfinity;
                    break;
            }
      
            rangeNavigator.ViewRangeStart = new DateTime(2015, 03, 01);
            rangeNavigator.ViewRangeEnd = new DateTime(2015, 07, 01);
            rangeNavigator.SetBinding(SfDateTimeRangeNavigator.ItemsSourceProperty, "DateTimeRangeData");
            rangeNavigator.XBindingPath = "XValue";
            rangeNavigator.YBindingPath = "YValue";

            contentChart.PrimaryAxis = new DateTimeAxis { ShowMajorGridLines = false, IsVisible = false };
            contentChart.SecondaryAxis = new NumericalAxis { ShowMajorGridLines = false, IsVisible = false };

            LineSeries lineSeries = new LineSeries();
            lineSeries.Color = Color.Red;                    
            lineSeries.SetBinding(ChartSeries.ItemsSourceProperty, "DateTimeRangeData");
            lineSeries.XBindingPath = "XValue";
            lineSeries.YBindingPath = "YValue";
            contentChart.Series.Add(lineSeries);

            rangeNavigator.Content = contentChart;

            rangeNavigator.RangeChanged += RangeNavigator_RangeChanged;

            #endregion

            var wrapperGrid = new Grid
            {
                VerticalOptions = LayoutOptions.FillAndExpand,
                HorizontalOptions = LayoutOptions.FillAndExpand,
                RowDefinitions =
                {
                    new RowDefinition {Height = new GridLength(0.75,GridUnitType.Star) },
                    new RowDefinition {Height = new GridLength(0.25,GridUnitType.Star)},
                 },
            };

            wrapperGrid.Children.Add(chart, 0, 0);
            wrapperGrid.Children.Add(rangeNavigator, 0, 1);

            return wrapperGrid;
        }
        private void RangeNavigator_RangeChanged(object sender, RangeChangedEventArgs e)
        {
            primaryAxis.Minimum = e.ViewRangeStartDate;

            primaryAxis.Maximum = e.ViewRangeEndDate;
        }
    }
}